import { Dialog, DialogActions, DialogContent, DialogContentText, DialogTitle, Button } from '@mui/material';
import { useRef, useState } from 'react';
import type { ModalFuncProps } from 'antd';
export const Confirm = ({
  open,
  onClose,
  title,
  content,
  onConfirm,
  okText = '确认',
  cancelText = '取消',
}: {
  open: boolean;
  onClose: () => void;
  title: string;
  content: string;
  onConfirm?: () => void;
  okText?: string;
  cancelText?: string;
}) => {
  return (
    <Dialog
      open={open}
      onClose={onClose}
      aria-labelledby='alert-dialog-title'
      aria-describedby='alert-dialog-description'>
      <DialogTitle id='alert-dialog-title' className='text-secondary min-w-[300px]'>
        {title}
      </DialogTitle>
      <DialogContent>
        <DialogContentText id='alert-dialog-description'>{content}</DialogContentText>
      </DialogContent>
      <DialogActions>
        <Button onClick={onClose} color='primary'>
          {cancelText || '取消'}
        </Button>
        <Button onClick={onConfirm} variant='contained' color='primary' autoFocus>
          {okText || '确认'}
        </Button>
      </DialogActions>
    </Dialog>
  );
};

type Fn = () => void;
export const useModal = () => {
  const [open, setOpen] = useState(false);
  const [title, setTitle] = useState('');
  const [content, setContent] = useState('');
  const fns = useRef<{
    onConfirm: Fn;
    onCancel: Fn;
    okText: string;
    cancelText: string;
  }>({
    onConfirm: () => {},
    onCancel: () => {},
    okText: '确认',
    cancelText: '取消',
  });
  const modal = {
    confirm: (props: ModalFuncProps) => {
      setOpen(true);
      setTitle(props.title as string);
      setContent(props.content as string);
      fns.current.onConfirm = async () => {
        const isClose = await props.onOk?.();
        if (!isClose) {
          setOpen(false);
        }
      };
      fns.current.onCancel = async () => {
        await props.onCancel?.();
        setOpen(false);
      };
      fns.current.okText = props.okText as string;
      fns.current.cancelText = props.cancelText as string;
    },
    cancel: () => {
      setOpen(false);
      fns.current.onCancel();
    },
  };
  const contextHolder = (
    <Confirm
      open={open}
      okText={fns.current.okText}
      cancelText={fns.current.cancelText}
      onClose={() => {
        setOpen(false);
        fns.current.onCancel();
      }}
      title={title}
      content={content}
      onConfirm={fns.current.onConfirm}
    />
  );
  return [modal, contextHolder] as [typeof modal, React.ReactNode];
};
